<?php
require_once __DIR__ . '/../DBconnection.php';

class CategoriaController extends DBconnection
{
    public function getCategorias()
    {
        $query = "SELECT
            c.id as id_categoria,
            es.nombre as nombre_es,
            en.nombre as nombre_en,
            c.destacado,
            c.status
        FROM categoria c
        LEFT JOIN categoria_i18n es ON c.id = es.id_categoria AND es.language = 'es'
        LEFT JOIN categoria_i18n en ON c.id = en.id_categoria AND en.language = 'en'
        ORDER BY C.status DESC, C.destacado DESC, es.nombre DESC";
        
        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode($result);
    }
    
    public function addCategoria()
    {
        $nombre_es = $_POST['nombre_es'];
        $nombre_en = $_POST['nombre_en'];
        $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;
        
        // Validar que los nombres no estén vacíos
        if (empty($nombre_es) || empty($nombre_en)) {
            echo json_encode(['status' => 'error', 'message' => 'Los nombres de categoría son obligatorios']);
            return;
        }
        
        // Verificar si ya existe una categoría con ese nombre
        $query = "SELECT COUNT(*) FROM categoria c 
                 JOIN categoria_i18n i18n ON c.id = i18n.id_categoria 
                 WHERE i18n.nombre = ? AND (i18n.language = 'es' OR i18n.language = 'en')";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$nombre_es]);
        $count = $stmt->fetchColumn();
        
        if ($count > 0) {
            echo json_encode(['status' => 'error', 'message' => 'Ya existe una categoría con ese nombre']);
            return;
        }
        
        try {
            $pdo = $this->connect();
            $pdo->beginTransaction();
            
            // Insertar categoría principal
            $query = "INSERT INTO categoria (destacado, status) VALUES (?, 1)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$destacado]);
            
            $id_categoria = $pdo->lastInsertId();
            
            // Insertar traducción en español
            $query = "INSERT INTO categoria_i18n (id_categoria, language, nombre) VALUES (?, 'es', ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_categoria, $nombre_es]);
            
            // Insertar traducción en inglés
            $query = "INSERT INTO categoria_i18n (id_categoria, language, nombre) VALUES (?, 'en', ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_categoria, $nombre_en]);
            
            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Categoría agregada correctamente']);
            
        } catch (Exception $e) {
            $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al agregar la categoría: ' . $e->getMessage()]);
        }
    }
    
    public function getCategoria()
    {
        $id = $_POST['id'];
        
        $query = "SELECT
            c.id as id_categoria,
            es.nombre as nombre_es,
            en.nombre as nombre_en,
            c.destacado,
            c.status
        FROM categoria c
        LEFT JOIN categoria_i18n es ON c.id = es.id_categoria AND es.language = 'es'
        LEFT JOIN categoria_i18n en ON c.id = en.id_categoria AND en.language = 'en'
        WHERE c.id = ?";
        
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$id]);
        $categoria = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($categoria) {
            echo json_encode($categoria);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Categoría no encontrada']);
        }
    }
    
    public function updateCategoria()
    {
        $id_categoria = $_POST['id_categoria'];
        $nombre_es = $_POST['nombre_es'];
        $nombre_en = $_POST['nombre_en'];
        $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;
        
        // Validar que los nombres no estén vacíos
        if (empty($nombre_es) || empty($nombre_en)) {
            echo json_encode(['status' => 'error', 'message' => 'Los nombres de categoría son obligatorios']);
            return;
        }
        
        // Verificar si ya existe otra categoría con ese nombre (excepto la actual)
        $query = "SELECT COUNT(*) FROM categoria c 
                 JOIN categoria_i18n i18n ON c.id = i18n.id_categoria 
                 WHERE i18n.nombre = ? AND c.id != ? AND (i18n.language = 'es' OR i18n.language = 'en')";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$nombre_es, $id_categoria]);
        $count = $stmt->fetchColumn();
        
        if ($count > 0) {
            echo json_encode(['status' => 'error', 'message' => 'Ya existe otra categoría con ese nombre']);
            return;
        }
        
        try {
            $pdo = $this->connect();
            $pdo->beginTransaction();
            
            // Actualizar categoría principal
            $query = "UPDATE categoria SET destacado = ? WHERE id = ?";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$destacado, $id_categoria]);
            
            // Actualizar traducción en español
            $query = "UPDATE categoria_i18n SET nombre = ? WHERE id_categoria = ? AND language = 'es'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_es, $id_categoria]);
            
            // Actualizar traducción en inglés
            $query = "UPDATE categoria_i18n SET nombre = ? WHERE id_categoria = ? AND language = 'en'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_en, $id_categoria]);
            
            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Categoría actualizada correctamente']);
            
        } catch (Exception $e) {
            $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al actualizar la categoría: ' . $e->getMessage()]);
        }
    }
    
    public function deactivateCategoria()
    {
        $id = $_POST['id'];
        
        
        // Baja lógica de la categoría (cambiar status a 0)
        $query = "UPDATE categoria SET status = 0, destacado = 0 WHERE id = ?";
        $stmt = $this->connect()->prepare($query);
        $result = $stmt->execute([$id]);
        
        if ($result) {
            echo json_encode(['status' => 'success', 'message' => 'Categoría eliminada correctamente']);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Error al eliminar la categoría']);
        }
    }

    public function activateCategoria()
    {
        $id = $_POST['id'];
        
        // Activar la categoría (cambiar status a 1)
        $query = "UPDATE categoria SET status = 1 WHERE id = ?";
        $stmt = $this->connect()->prepare($query);
        $result = $stmt->execute([$id]);
        
        if ($result) {
            echo json_encode(['status' => 'success', 'message' => 'Categoría activada correctamente']);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Error al activar la categoría']);
        }
    }
}