<?php
require_once __DIR__ . '/../DBconnection.php';

class ProductosController extends DBconnection
{
    public function getProductos()
    {
        $query = "SELECT 
                    p.id as id_producto,
                    p.id_subcategoria,
                    p.sku,
                    p.pdf,
                    p.autocard,
                    p.destacado,
                    p.status,
                    p_es.nombre as nombre_es,
                    p_es.descripcion as descripcion_es,
                    p_en.nombre as nombre_en,
                    p_en.descripcion as descripcion_en,
                    s_es.nombre as subcategoria_es,
                    s_en.nombre as subcategoria_en,
                    c_es.nombre as categoria_es,
                    c_en.nombre as categoria_en,
                    (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 0,1) as imagen_principal
                FROM 
                    producto p
                LEFT JOIN producto_i18n p_es ON p.id = p_es.id_producto AND p_es.language = 'es'
                LEFT JOIN producto_i18n p_en ON p.id = p_en.id_producto AND p_en.language = 'en'
                LEFT JOIN subcategoria s ON p.id_subcategoria = s.id
                LEFT JOIN subcategoria_i18n s_es ON s.id = s_es.id_subcategoria AND s_es.language = 'es'
                LEFT JOIN subcategoria_i18n s_en ON s.id = s_en.id_subcategoria AND s_en.language = 'en'
                LEFT JOIN categoria c ON s.id_cat = c.id
                LEFT JOIN categoria_i18n c_es ON c.id = c_es.id_categoria AND c_es.language = 'es'
                LEFT JOIN categoria_i18n c_en ON c.id = c_en.id_categoria AND c_en.language = 'en'
                ORDER BY p.id DESC";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode($result);
    }

    public function getProducto()
    {
        $id = $_POST['id'];

        $query = "SELECT 
                p.id as id_producto,
                p.id_subcategoria,
                p.sku,
                p.pdf,
                p.autocard,
                p.destacado,
                p.status,
                p_es.nombre as nombre_es,
                p_es.descripcion as descripcion_es,
                p_en.nombre as nombre_en,
                p_en.descripcion as descripcion_en,
                s_es.nombre as subcategoria_es,
                s_en.nombre as subcategoria_en,
                c_es.nombre as categoria_es,
                c_en.nombre as categoria_en, 
                (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 0,1) AS imagen1,
                (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 1,1) AS imagen2,                    
                (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 2,1) AS imagen3,
                (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 3,1) AS imagen4,
                (SELECT ip.imagen FROM imagen_producto ip
                WHERE ip.id_producto = p.id
                ORDER BY (ip.principal=1) DESC, ip.id LIMIT 4,1) AS imagen5
            FROM 
                producto p
            LEFT JOIN producto_i18n p_es ON p.id = p_es.id_producto AND p_es.language = 'es'
            LEFT JOIN producto_i18n p_en ON p.id = p_en.id_producto AND p_en.language = 'en'
            LEFT JOIN subcategoria s ON p.id_subcategoria = s.id
            LEFT JOIN subcategoria_i18n s_es ON s.id = s_es.id_subcategoria AND s_es.language = 'es'
            LEFT JOIN subcategoria_i18n s_en ON s.id = s_en.id_subcategoria AND s_en.language = 'en'
            LEFT JOIN categoria c ON s.id_cat = c.id
            LEFT JOIN categoria_i18n c_es ON c.id = c_es.id_categoria AND c_es.language = 'es'
            LEFT JOIN categoria_i18n c_en ON c.id = c_en.id_categoria AND c_en.language = 'en'
            WHERE p.id = ?";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$id]);
        $producto = $stmt->fetch(PDO::FETCH_ASSOC);

        // Obtener imágenes del producto
        if ($producto) {
            // Primero buscamos una imagen marcada como principal
            $queryPrincipal = "SELECT imagen FROM imagen_producto WHERE id_producto = ? AND principal = 1 LIMIT 1";
            $stmtPrincipal = $this->connect()->prepare($queryPrincipal);
            $stmtPrincipal->execute([$id]);
            $imagenPrincipal = $stmtPrincipal->fetchColumn();

            // Si no hay imagen principal marcada, seleccionaremos la primera
            if (!$imagenPrincipal) {
                $queryPrincipal = "SELECT imagen FROM imagen_producto WHERE id_producto = ? ORDER BY id ASC LIMIT 1";
                $stmtPrincipal = $this->connect()->prepare($queryPrincipal);
                $stmtPrincipal->execute([$id]);
                $imagenPrincipal = $stmtPrincipal->fetchColumn();
            }

            $producto['imagen_principal'] = $imagenPrincipal;

            // Obtener todas las imágenes (hasta 5)
            $queryImagenes = "SELECT id, imagen, principal FROM imagen_producto WHERE id_producto = ? ORDER BY principal DESC, id ASC LIMIT 5";
            $stmtImagenes = $this->connect()->prepare($queryImagenes);
            $stmtImagenes->execute([$id]);
            $imagenes = $stmtImagenes->fetchAll(PDO::FETCH_ASSOC);

            // Si no hay imagen marcada como principal pero tenemos imágenes, marcar la primera
            if (!$imagenPrincipal && count($imagenes) > 0 && !$imagenes[0]['principal']) {
                $updatePrincipal = "UPDATE imagen_producto SET principal = 1 WHERE id = ?";
                $stmtUpdatePrincipal = $this->connect()->prepare($updatePrincipal);
                $stmtUpdatePrincipal->execute([$imagenes[0]['id']]);
                $imagenes[0]['principal'] = 1;
            }

            $producto['imagenes'] = $imagenes;

            echo json_encode($producto);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Producto no encontrado']);
        }
    }
    public function getActiveSubcategorias()
    {
        $query = "SELECT
                    s.id as id_subcategoria,
                    s_es.nombre as nombre_es,
                    s_en.nombre as nombre_en,
                    c.id as id_categoria,
                    c_es.nombre as categoria_es,
                    c_en.nombre as categoria_en
                FROM 
                    subcategoria s
                LEFT JOIN subcategoria_i18n s_es ON s.id = s_es.id_subcategoria AND s_es.language = 'es'
                LEFT JOIN subcategoria_i18n s_en ON s.id = s_en.id_subcategoria AND s_en.language = 'en'
                LEFT JOIN categoria c ON s.id_cat = c.id
                LEFT JOIN categoria_i18n c_es ON c.id = c_es.id_categoria AND c_es.language = 'es'
                LEFT JOIN categoria_i18n c_en ON c.id = c_en.id_categoria AND c_en.language = 'en'
                WHERE s.status = 1 AND c.status = 1
                ORDER BY c_es.nombre ASC, s_es.nombre ASC";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode($result);
    }

    public function createProducto()
    {
        try {
            $nombre_es = $_POST['nombre_es'];
            $nombre_en = $_POST['nombre_en'];
            $descripcion_es = $_POST['descripcion_es'];
            $descripcion_en = $_POST['descripcion_en'];
            $id_subcategoria = $_POST['id_subcategoria'];
            $sku = $_POST['sku'];
            $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;

            // Validaciones básicas
            if (empty($nombre_es) || empty($nombre_en) || empty($id_subcategoria) || empty($sku)) {
                echo json_encode(['status' => 'error', 'message' => 'Todos los campos marcados son obligatorios']);
                return;
            }

            // Verificar si ya existe un producto con ese SKU
            $checkQuery = "SELECT COUNT(*) FROM producto WHERE sku = ?";
            $checkStmt = $this->connect()->prepare($checkQuery);
            $checkStmt->execute([$sku]);
            if ($checkStmt->fetchColumn() > 0) {
                echo json_encode(['status' => 'error', 'message' => 'Ya existe un producto con ese SKU']);
                return;
            }

            $pdo = $this->connect();
            $pdo->beginTransaction();

            // Insertar producto principal
            $query = "INSERT INTO producto (id_subcategoria, sku, pdf, autocard, destacado, status) 
                      VALUES (?, ?, ?, ?, ?, 1)";
            $stmt = $pdo->prepare($query);

            $pdf = isset($_POST['pdf']) ? $_POST['pdf'] : null;
            $autocard = isset($_POST['autocard']) ? $_POST['autocard'] : null;

            $stmt->execute([$id_subcategoria, $sku, $pdf, $autocard, $destacado]);
            $id_producto = $pdo->lastInsertId();

            // Insertar traducción en español
            $query = "INSERT INTO producto_i18n (id_producto, language, nombre, descripcion) 
                      VALUES (?, 'es', ?, ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_producto, $nombre_es, $descripcion_es]);

            // Insertar traducción en inglés
            $query = "INSERT INTO producto_i18n (id_producto, language, nombre, descripcion) 
                      VALUES (?, 'en', ?, ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_producto, $nombre_en, $descripcion_en]);

            // Procesar imágenes si existen
            if (isset($_POST['imagenes']) && !empty($_POST['imagenes'])) {
                $imagenes = explode(',', $_POST['imagenes']);
                foreach ($imagenes as $imagen) {
                    $query = "INSERT INTO imagen_producto (id_producto, imagen) VALUES (?, ?)";
                    $stmt = $pdo->prepare($query);
                    $stmt->execute([$id_producto, trim($imagen)]);
                }
            }

            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Producto creado correctamente', 'id' => $id_producto]);
        } catch (Exception $e) {
            if (isset($pdo)) $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al crear el producto: ' . $e->getMessage()]);
        }
    }

    // Método para actualizar un producto    
    public function updateProducto()
    {
        try {
            $id_producto = $_POST['id_producto'];
            $nombre_es = $_POST['nombre_es'];
            $nombre_en = $_POST['nombre_en'];
            $descripcion_es = $_POST['descripcion_es'];
            $descripcion_en = $_POST['descripcion_en'];
            $id_subcategoria = $_POST['id_subcategoria'];
            $sku = $_POST['sku'];
            $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;

            // Validaciones básicas
            if (empty($id_producto) || empty($nombre_es) || empty($nombre_en) || empty($id_subcategoria) || empty($sku)) {
                echo json_encode(['status' => 'error', 'message' => 'Todos los campos marcados son obligatorios']);
                return;
            }

            // Verificar SKU único
            $checkQuery = "SELECT COUNT(*) FROM producto WHERE sku = ? AND id != ?";
            $checkStmt = $this->connect()->prepare($checkQuery);
            $checkStmt->execute([$sku, $id_producto]);
            if ($checkStmt->fetchColumn() > 0) {
                echo json_encode(['status' => 'error', 'message' => 'Ya existe otro producto con ese SKU']);
                return;
            }

            $pdo = $this->connect();
            $pdo->beginTransaction();

            // Actualizar producto principal
            $query = "UPDATE producto SET id_subcategoria = ?, sku = ?, destacado = ?";
            $params = [$id_subcategoria, $sku, $destacado];

            // Añadir PDF y AutoCAD si están definidos
            if (isset($_POST['pdf']) && !empty($_POST['pdf'])) {
                $query .= ", pdf = ?";
                $params[] = $_POST['pdf'];
            }

            if (isset($_POST['autocard']) && !empty($_POST['autocard'])) {
                $query .= ", autocard = ?";
                $params[] = $_POST['autocard'];
            }

            $query .= " WHERE id = ?";
            $params[] = $id_producto;

            $stmt = $pdo->prepare($query);
            $stmt->execute($params);

            // Actualizar traducciones
            $query = "UPDATE producto_i18n SET nombre = ?, descripcion = ? 
                  WHERE id_producto = ? AND language = 'es'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_es, $descripcion_es, $id_producto]);

            $query = "UPDATE producto_i18n SET nombre = ?, descripcion = ? 
                  WHERE id_producto = ? AND language = 'en'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_en, $descripcion_en, $id_producto]);

            // Procesar imágenes si se envía un nuevo conjunto
            if (isset($_POST['imagenes']) && $_POST['imagenes'] !== '') {
                // Eliminar imágenes existentes
                $query = "DELETE FROM imagen_producto WHERE id_producto = ?";
                $stmt = $pdo->prepare($query);
                $stmt->execute([$id_producto]);

                // Insertar nuevas imágenes
                $imagenes = explode(',', $_POST['imagenes']);
                $imagen_principal = isset($_POST['imagen_principal']) ? $_POST['imagen_principal'] : null;

                foreach ($imagenes as $imagen) {
                    if (trim($imagen) !== '') {
                        $principal = ($imagen_principal && trim($imagen) === trim($imagen_principal)) ? 1 : 0;

                        // Insertamos la imagen en la tabla imagen_producto
                        $query = "INSERT INTO imagen_producto (id_producto, imagen, principal) VALUES (?, ?, ?)";
                        $stmt = $pdo->prepare($query);
                        $stmt->execute([$id_producto, trim($imagen), $principal]);
                    }
                }
            }

            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Producto actualizado correctamente']);
        } catch (Exception $e) {
            if (isset($pdo)) $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al actualizar el producto: ' . $e->getMessage()]);
        }
    }

    // Añadir un nuevo método para establecer la imagen principal
    public function setImagenPrincipal()
    {
        try {
            $id_producto = $_POST['id_producto'];
            $imagen_principal = $_POST['imagen_principal'];

            if (empty($id_producto) || empty($imagen_principal)) {
                echo json_encode(['status' => 'error', 'message' => 'Datos incompletos']);
                return;
            }

            $pdo = $this->connect();
            $pdo->beginTransaction();

            // Quitar marca principal de todas las imágenes del producto
            $queryReset = "UPDATE imagen_producto SET principal = 0 WHERE id_producto = ?";
            $stmtReset = $pdo->prepare($queryReset);
            $stmtReset->execute([$id_producto]);

            // Establecer la nueva imagen principal
            $querySet = "UPDATE imagen_producto SET principal = 1 
                    WHERE id_producto = ? AND imagen = ?";
            $stmtSet = $pdo->prepare($querySet);
            $stmtSet->execute([$id_producto, $imagen_principal]);

            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Imagen principal actualizada']);
        } catch (Exception $e) {
            if (isset($pdo)) $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error: ' . $e->getMessage()]);
        }
    }

    public function deleteProducto()
    {
        $id = $_POST['id'];

        try {
            $query = "UPDATE producto SET status = 0 WHERE id = ?";
            $stmt = $this->connect()->prepare($query);
            $result = $stmt->execute([$id]);

            if ($result) {
                echo json_encode(['status' => 'success', 'message' => 'Producto desactivado correctamente']);
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Error al desactivar el producto']);
            }
        } catch (Exception $e) {
            echo json_encode(['status' => 'error', 'message' => 'Error: ' . $e->getMessage()]);
        }
    }

    public function activateProducto()
    {
        $id = $_POST['id'];

        try {
            $query = "UPDATE producto SET status = 1 WHERE id = ?";
            $stmt = $this->connect()->prepare($query);
            $result = $stmt->execute([$id]);

            if ($result) {
                echo json_encode(['status' => 'success', 'message' => 'Producto activado correctamente']);
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Error al activar el producto']);
            }
        } catch (Exception $e) {
            echo json_encode(['status' => 'error', 'message' => 'Error: ' . $e->getMessage()]);
        }
    }
}
