<?php
require_once __DIR__ . '/../DBconnection.php';

class SubcategoriaController extends DBconnection
{
    public function getSubcategorias()
    {
        $query = "SELECT
            s.id as id_subcategoria,
            s.id_cat,
            s_es.nombre as nombre_es,
            s_en.nombre as nombre_en,
            c_es.nombre as categoria_es,
            c_en.nombre as categoria_en,
            s.destacado,
            s.status
        FROM subcategoria s
        LEFT JOIN subcategoria_i18n s_es ON s.id = s_es.id_subcategoria AND s_es.language = 'es'
        LEFT JOIN subcategoria_i18n s_en ON s.id = s_en.id_subcategoria AND s_en.language = 'en'
        LEFT JOIN categoria c ON s.id_cat = c.id
        LEFT JOIN categoria_i18n c_es ON c.id = c_es.id_categoria AND c_es.language = 'es'
        LEFT JOIN categoria_i18n c_en ON c.id = c_en.id_categoria AND c_en.language = 'en'
        ORDER BY s.status DESC, s.destacado DESC, s_es.nombre DESC";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode($result);
    }

    public function getActiveCategories()
    {
        $query = "SELECT
            c.id as id_categoria,
            es.nombre as nombre_es,
            en.nombre as nombre_en
        FROM categoria c
        LEFT JOIN categoria_i18n es ON c.id = es.id_categoria AND es.language = 'es'
        LEFT JOIN categoria_i18n en ON c.id = en.id_categoria AND en.language = 'en'
        WHERE c.status = 1
        ORDER BY es.nombre ASC";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode($result);
    }

    public function addSubcategoria()
    {
        $nombre_es = $_POST['nombre_es'];
        $nombre_en = $_POST['nombre_en'];
        $id_cat = $_POST['id_cat'];
        $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;

        // Validar que los nombres y la categoría no estén vacíos
        if (empty($nombre_es) || empty($nombre_en) || empty($id_cat)) {
            echo json_encode(['status' => 'error', 'message' => 'Todos los campos son obligatorios']);
            return;
        }

        // Verificar si ya existe una subcategoría con ese nombre
        $query = "SELECT COUNT(*) FROM subcategoria s 
                 JOIN subcategoria_i18n i18n ON s.id = i18n.id_subcategoria 
                 WHERE i18n.nombre = ? AND (i18n.language = 'es' OR i18n.language = 'en')";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$nombre_es]);
        $count = $stmt->fetchColumn();

        if ($count > 0) {
            echo json_encode(['status' => 'error', 'message' => 'Ya existe una subcategoría con ese nombre']);
            return;
        }

        try {
            $pdo = $this->connect();
            $pdo->beginTransaction();

            // Insertar subcategoría principal
            $query = "INSERT INTO subcategoria (id_cat, destacado, status) VALUES (?, ?, 1)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_cat, $destacado]);

            $id_subcategoria = $pdo->lastInsertId();

            // Insertar traducción en español
            $query = "INSERT INTO subcategoria_i18n (id_subcategoria, language, nombre) VALUES (?, 'es', ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_subcategoria, $nombre_es]);

            // Insertar traducción en inglés
            $query = "INSERT INTO subcategoria_i18n (id_subcategoria, language, nombre) VALUES (?, 'en', ?)";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_subcategoria, $nombre_en]);

            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Subcategoría agregada correctamente']);
        } catch (Exception $e) {
            $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al agregar la subcategoría: ' . $e->getMessage()]);
        }
    }

    public function getSubcategoria()
    {
        $id = $_POST['id'];

        $query = "SELECT
            s.id as id_subcategoria,
            s.id_cat,
            s_es.nombre as nombre_es,
            s_en.nombre as nombre_en,
            s.destacado,
            s.status
        FROM subcategoria s
        LEFT JOIN subcategoria_i18n s_es ON s.id = s_es.id_subcategoria AND s_es.language = 'es'
        LEFT JOIN subcategoria_i18n s_en ON s.id = s_en.id_subcategoria AND s_en.language = 'en'
        WHERE s.id = ?";

        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$id]);
        $subcategoria = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($subcategoria) {
            echo json_encode($subcategoria);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Subcategoría no encontrada']);
        }
    }

    public function updateSubcategoria()
    {
        $id_subcategoria = $_POST['id_subcategoria'];
        $nombre_es = $_POST['nombre_es'];
        $nombre_en = $_POST['nombre_en'];
        $id_cat = $_POST['id_cat'];
        $destacado = isset($_POST['destacado']) ? $_POST['destacado'] : 0;

        // Validar que los nombres y la categoría no estén vacíos
        if (empty($nombre_es) || empty($nombre_en) || empty($id_cat)) {
            echo json_encode(['status' => 'error', 'message' => 'Todos los campos son obligatorios']);
            return;
        }

        // Verificar si ya existe otra subcategoría con ese nombre (excepto la actual)
        $query = "SELECT COUNT(*) FROM subcategoria s 
                 JOIN subcategoria_i18n i18n ON s.id = i18n.id_subcategoria 
                 WHERE i18n.nombre = ? AND s.id != ? AND (i18n.language = 'es' OR i18n.language = 'en')";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$nombre_es, $id_subcategoria]);
        $count = $stmt->fetchColumn();

        if ($count > 0) {
            echo json_encode(['status' => 'error', 'message' => 'Ya existe otra subcategoría con ese nombre']);
            return;
        }

        try {
            $pdo = $this->connect();
            $pdo->beginTransaction();

            // Actualizar subcategoría principal
            $query = "UPDATE subcategoria SET id_cat = ?, destacado = ? WHERE id = ?";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$id_cat, $destacado, $id_subcategoria]);

            // Actualizar traducción en español
            $query = "UPDATE subcategoria_i18n SET nombre = ? WHERE id_subcategoria = ? AND language = 'es'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_es, $id_subcategoria]);

            // Actualizar traducción en inglés
            $query = "UPDATE subcategoria_i18n SET nombre = ? WHERE id_subcategoria = ? AND language = 'en'";
            $stmt = $pdo->prepare($query);
            $stmt->execute([$nombre_en, $id_subcategoria]);

            $pdo->commit();
            echo json_encode(['status' => 'success', 'message' => 'Subcategoría actualizada correctamente']);
        } catch (Exception $e) {
            $pdo->rollBack();
            echo json_encode(['status' => 'error', 'message' => 'Error al actualizar la subcategoría: ' . $e->getMessage()]);
        }
    }

    public function deactivateSubcategoria()
    {
        $id = $_POST['id'];

        // Comprobar si la subcategoría tiene productos asociados
        $query = "SELECT COUNT(*) FROM producto WHERE id_subcategoria = ?";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute([$id]);
        $count = $stmt->fetchColumn();

        if ($count > 0) {
            echo json_encode(['status' => 'error', 'message' => 'No se puede desactivar la subcategoría porque tiene productos asociados']);
            return;
        }

        // Baja lógica de la subcategoría (cambiar status a 0)
        $query = "UPDATE subcategoria SET status = 0, destacado = 0 WHERE id = ?";
        $stmt = $this->connect()->prepare($query);
        $result = $stmt->execute([$id]);

        if ($result) {
            echo json_encode(['status' => 'success', 'message' => 'Subcategoría desactivada correctamente']);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Error al desactivar la subcategoría']);
        }
    }

    public function activateSubcategoria()
    {
        $id = $_POST['id'];

        // Activar la subcategoría (cambiar status a 1)
        $query = "UPDATE subcategoria SET status = 1 WHERE id = ?";
        $stmt = $this->connect()->prepare($query);
        $result = $stmt->execute([$id]);

        if ($result) {
            echo json_encode(['status' => 'success', 'message' => 'Subcategoría activada correctamente']);
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Error al activar la subcategoría']);
        }
    }
}
