<?php
require_once '../DBconnection.php';

class DashboardModel extends DBconnection
{
    public function getStats()
    {
        $stats = [];
        $stats['totalCategorias'] = $this->getCount('categoria');
        $stats['totalSubcategorias'] = $this->getCount('subcategoria');
        $stats['totalProductos'] = $this->getCount('producto');
        $stats['totalUsuarios'] = $this->getCount('usuario');
        echo json_encode($stats);
    }

    public function getProductosByCategoria()
    {
        $query = "SELECT ci.nombre AS categoria, COUNT(p.id) AS total
                  FROM producto p
                  JOIN subcategoria sc ON p.id_subcategoria = sc.id
                  JOIN categoria c ON sc.id_cat = c.id
                  JOIN categoria_i18n ci ON c.id = ci.id_categoria
                  WHERE p.status = 1 AND ci.language = 'es'
                  GROUP BY ci.nombre";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $labels = array_column($result, 'categoria');
        $values = array_column($result, 'total');
        echo json_encode(['labels' => $labels, 'values' => $values]);
    }

    public function getProductosDestacados()
    {
        $query = "SELECT 
                    CASE WHEN destacado = 1 THEN 'Destacados' ELSE 'No Destacados' END AS tipo,
                    COUNT(id) AS total 
                  FROM producto 
                  WHERE status = 1
                  GROUP BY destacado";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $labels = array_column($result, 'tipo');
        $values = array_column($result, 'total');
        echo json_encode(['labels' => $labels, 'values' => $values]);
    }

    public function getLastProductos()
    {
        $query = "SELECT 
                    p.id, 
                    pi.nombre, 
                    p.sku, 
                    ci.nombre AS categoria, 
                    sci.nombre AS subcategoria
                  FROM producto p
                  JOIN producto_i18n pi ON p.id = pi.id_producto AND pi.language = 'es'
                  JOIN subcategoria sc ON p.id_subcategoria = sc.id
                  JOIN subcategoria_i18n sci ON sc.id = sci.id_subcategoria AND sci.language = 'es'
                  JOIN categoria c ON sc.id_cat = c.id
                  JOIN categoria_i18n ci ON c.id = ci.id_categoria AND ci.language = 'es'
                  WHERE p.status = 1
                  ORDER BY p.id DESC LIMIT 10";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode($result);
    }

    private function getCount($table)
    {
        $query = "SELECT COUNT(*) AS total FROM $table WHERE status = 1";
        $stmt = $this->connect()->prepare($query);
        $stmt->execute();
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        return $result['total'];
    }
}

if (isset($_POST['action'])) {
    $dashboard = new DashboardModel();
    switch ($_POST['action']) {
        case 'getStats':
            $dashboard->getStats();
            break;
        case 'getProductosByCategoria':
            $dashboard->getProductosByCategoria();
            break;
        case 'getProductosDestacados':
            $dashboard->getProductosDestacados();
            break;
        case 'getLastProductos':
            $dashboard->getLastProductos();
            break;
    }
}