$(document).ready(function () {

    $("#parque_id").select2({
        placeholder: "Selecciona un parque industrial",
        allowClear: true,
        minimumResultsForSearch: 0
    });
    loadBanners();

    initializeDropzone();
});

function loadBanners() {
    $.ajax({
        url: 'database/model/banners.php',
        type: 'POST',
        data: { action: 'getBanners' },
        success: function (response) {
            let banners = JSON.parse(response);
            let sortableList = $('#sortableBanners');
            sortableList.empty();

            if (banners.length === 0) {
                sortableList.append('<li class="list-group-item text-center">Sin banners registrados</li>');
                return;
            }

            console.log(banners);
            banners.forEach(banner => {
                sortableList.append(`
                    <li class="list-group-item d-flex align-items-center" data-id="${banner.id}">
                        <div class="col-4">
                            <img src="img/banners/${banner.banner}" alt="Banner" class="banner-img" style="width: 100px; height: auto;">
                        </div>
                        <div class="col-4">
                            <span>${banner.nombre_parque || ''}</span>
                        </div>
                        <div class="col-2">
                            <span>${banner.ciudad || ''}, ${banner.estado || ''}</span>
                        </div>
                        <div class="col-2 text-end">
                            <button class="btn btn-primary btn-sm me-2" onclick="editBanner(${banner.id})">
                                <i class="fa-solid fa-pen-to-square"></i> Editar
                            </button>
                            <button class="btn btn-danger btn-sm" onclick="deleteBanner(${banner.id})">
                                <i class="fa-solid fa-trash"></i> Eliminar
                            </button>
                        </div>
                    </li>
                `);
            });

            initializeSortable();
        },
        error: function (error) {
            console.log("Error:", error);
        }
    });
}

function initializeSortable() {
    new Sortable(document.getElementById('sortableBanners'), {
        animation: 150,
        onEnd: function () {
            let order = [];
            $('#sortableBanners li').each(function () {
                order.push($(this).data('id'));
            });

            $.ajax({
                url: 'database/model/banners.php',
                type: 'POST',
                data: { action: 'updateOrder', order: order },
                success: function (response) {
                    let result = JSON.parse(response);
                    Swal.fire({
                        icon: result.status,
                        title: result.message,
                        showConfirmButton: false,
                        timer: 1500
                    });
                },
                error: function (error) {
                    console.error("Error al actualizar el orden:", error);
                }
            });
        }
    });
}

function initializeDropzone() {
    Dropzone.autoDiscover = false;

    if (Dropzone.instances.length > 0) {
        Dropzone.instances.forEach(instance => instance.destroy());
    }

    let bannerDropzone = new Dropzone("#bannerForm", {
        url: "database/model/banners.php",
        autoProcessQueue: false,
        uploadMultiple: false,
        acceptedFiles: ".jpg,.jpeg,.png,.gif",
        maxFiles: 1,
        addRemoveLinks: true,
        init: function () {
            let myDropzone = this;

            this.on("addedfile", function (file) {
                const maxFileSize = 1 * 1024 * 1024; // 1 MB
                if (file.size > maxFileSize) {
                    this.removeFile(file);
                    Swal.fire({
                        icon: "error",
                        title: "Archivo demasiado grande",
                        text: "El archivo supera el tamaño máximo permitido de 1 MB."
                    });
                } else {
                    let previewElement = $(file.previewElement);
                    let parqueInputDiv = $("#parque_id").closest(".mb-3");
                    previewElement.insertBefore(parqueInputDiv);
                }
            });

            $("#submitBanner").on("click", function () {
                let id = $("#id").val();
                let parque_id = $("#parque_id").val();
                let descripcion = $("#descripcion").val();

                if (!parque_id) {
                    Swal.fire({
                        icon: "error",
                        title: "Error",
                        text: "Por favor, selecciona un parque."
                    });
                    return;
                }

                if (id) {
                    // Actualizar banner
                    let formData = new FormData();
                    formData.append("action", "updateBannerWithImage");
                    formData.append("id", id);
                    formData.append("parque_id", parque_id);
                    formData.append("descripcion", descripcion);

                    if (Dropzone.instances[0].getQueuedFiles().length > 0) {
                        formData.append("file", Dropzone.instances[0].getQueuedFiles()[0]);
                    }

                    $.ajax({
                        url: "database/model/banners.php",
                        type: "POST",
                        data: formData,
                        processData: false,
                        contentType: false,
                        success: function (response) {
                            let result = JSON.parse(response);
                            Swal.fire({
                                icon: result.status,
                                title: result.message,
                                showConfirmButton: false,
                                timer: 1500
                            }).then(() => {
                                if (result.status === "success") {
                                    location.reload();
                                }
                            });
                        },
                        error: function (xhr, status, error) {
                            console.error("Error:", error);
                            Swal.fire({
                                icon: "error",
                                title: "Error",
                                text: "Ocurrió un error al procesar la solicitud"
                            });
                        }
                    });
                } else {
                    // Crear nuevo banner
                    if (Dropzone.instances[0].getQueuedFiles().length === 0) {
                        Swal.fire({
                            icon: "error",
                            title: "Error",
                            text: "Por favor, selecciona una imagen antes de guardar."
                        });
                        return;
                    }

                    Dropzone.instances[0].options.params = {
                        action: "uploadBanner",
                        parque_id: parque_id,
                        descripcion: descripcion
                    };
                    Dropzone.instances[0].processQueue();
                }
            });

            myDropzone.on("complete", function (file) {
                let response = JSON.parse(file.xhr.response);
                Swal.fire({
                    icon: response.status,
                    title: response.message,
                    showConfirmButton: false,
                    timer: 1500
                }).then(() => {
                    if (response.status === "success") {
                        location.reload();
                    }
                });
            });

            $(".dz-message").html(
                `<p>Arrastra y suelta una imagen aquí</p>
                <p>o</p>
                <p>haz clic para seleccionar</p>
                <p class="dz-p">(Dimensiones: 1519x360px)</p>`
            );

            myDropzone.on("removedfile", function () {
                console.log("Archivo eliminado");
            });
        }
    });
}

function editBanner(id) {
    $.ajax({
        url: 'database/model/banners.php',
        type: 'POST',
        data: { action: 'getBanner', id: id },
        success: function (response) {
            let banner = JSON.parse(response);

            if (banner.status === 'error') {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: banner.message
                });
                return;
            }

            $('#parque_id').val(banner.parque_id).trigger('change');
            $('#descripcion').val(banner.descripcion);
            $('#id').val(banner.id);
            $('#bannersModalLabel').text('Editar Banner');
            $('#currentImage').attr('src', `img/banners/${banner.banner}`);
            $('#currentImageContainer').show();
            $('.dz-message').show();
            $('#bannersModal').modal('show');
        },
        error: function (error) {
            console.error("Error al obtener el banner:", error);
        }
    });
}

function deleteBanner(id) {
    Swal.fire({
        title: '¿Estás seguro?',
        text: "¡No podrás revertir esto!",
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: 'Sí, eliminarlo'
    }).then((result) => {
        if (result.isConfirmed) {
            $.ajax({
                url: 'database/model/banners.php',
                type: 'POST',
                data: { action: 'deleteBanner', id: id },
                success: function (response) {
                    let result = JSON.parse(response);
                    Swal.fire({
                        icon: result.status,
                        title: result.message,
                        showConfirmButton: false,
                        timer: 1500
                    }).then(() => {
                        if (result.status === "success") {
                            location.reload();
                        }
                    });
                },
                error: function (error) {
                    console.error("Error:", error);
                }
            });
        }
    });
}

$('#bannersModal').on('hidden.bs.modal', function () {
    $('#bannerForm')[0].reset();
    $('#id').val('');
    $('#currentImageContainer').hide();
    $('#currentImage').attr('src', '');
    $('.dz-message').show();
    if (Dropzone.instances.length > 0) {
        Dropzone.instances[0].removeAllFiles();
    }
    $('#bannersModalLabel').text('Agregar Banner');
});