$(document).ready(function () {
    loadCategories();

    // Limpiar el modal al cerrarlo
    $('#addCategoryModal').on('hidden.bs.modal', function () {
        $("#addCategoryForm")[0].reset();
        $("#id_categoria").val("");
        $("#addCategoryModalLabel").html('Añadir Categoría <i class="fa-solid fa-list"></i>');
        $("#btn-save-category").text("Guardar categoría");
    });

    // Botón guardar categoría
    $("#btn-save-category").click(function () {
        saveCategory();
    });

    // ===== TRADUCCIÓN AUTOMÁTICA =====
    let typingTimer;
    const doneTypingInterval = 800; // tiempo en ms (0.8 segundos)

    // Evento de entrada de texto en el campo español
    $("#nombre_es").on('input', function () {
        clearTimeout(typingTimer);
        const texto = $(this).val().trim();

        // Si el campo está vacío, también vaciamos el campo en inglés
        if (texto === '') {
            $("#nombre_en").val('');
            return;
        }

        // Iniciamos el temporizador para no sobrecargar la API
        typingTimer = setTimeout(function () {
            // Solo traducir si hay texto
            if (texto.length > 0) {
                // Primero probamos con diccionario local
                let traduccionLocal = localTranslate(texto);
                if (traduccionLocal) {
                    $("#nombre_en").val(traduccionLocal);
                } else {
                    // Si no hay coincidencia local, usamos API gratuita
                    translateText(texto);
                }
            }
        }, doneTypingInterval);
    });
});

// Función de traducción local con términos comunes
function localTranslate(text) {
    // Diccionario de términos comunes (ampliable)
    const commonTranslations = {
        "instalación eléctrica": "electrical installation",
        "poste de luz": "light pole",
        "tablero eléctrico": "electrical panel",
        "cable": "cable",
        "transformador": "transformer",
        "energía solar": "solar energy",
        "iluminación": "lighting",
        "panel solar": "solar panel",
        "interruptor": "switch",
        "tomacorriente": "power outlet",
        "conductor eléctrico": "electrical conductor",
        "clavija": "plug",
        "enchufe": "socket",
        "fusible": "fuse",
        "aislante": "insulator",
        "subestación": "substation",
        "generador": "generator",
        "batería": "battery",
        "inversor": "inverter",
        "electricista": "electrician",
        "herramientas": "tools",
        "instalador": "installer",
        "ducto": "duct",
        "canaleta": "cable tray",
        "conexión": "connection",
        "sistema eléctrico": "electrical system"
    };

    // Convertir a minúsculas para buscar en el diccionario
    const textLower = text.toLowerCase();

    // Comprobar si existe una traducción exacta
    if (commonTranslations[textLower]) {
        // Mantener la capitalización original
        if (text[0] === text[0].toUpperCase()) {
            return commonTranslations[textLower].charAt(0).toUpperCase() +
                commonTranslations[textLower].slice(1);
        }
        return commonTranslations[textLower];
    }

    // Devolver null si no hay coincidencia en el diccionario
    return null;
}

// Función para traducir texto usando un servicio gratuito
function translateText(text) {
    // Mostrar indicador de carga
    $("#nombre_en").addClass('loading-input');

    // Usar la API de MyMemory (gratuita con límites)
    $.ajax({
        url: `https://api.mymemory.translated.net/get?q=${encodeURIComponent(text)}&langpair=es|en`,
        type: 'GET',
        success: function (data) {
            if (data && data.responseData) {
                $("#nombre_en").val(data.responseData.translatedText);
            } else {
                fallbackTranslation(text);
            }
            $("#nombre_en").removeClass('loading-input');
        },
        error: function () {
            fallbackTranslation(text);
            $("#nombre_en").removeClass('loading-input');
        }
    });
}

// Función de respaldo si falla la primera opción
function fallbackTranslation(text) {
    // Usar LibreTranslate como alternativa
    $.ajax({
        url: 'https://libretranslate.de/translate',
        type: 'POST',
        data: JSON.stringify({
            q: text,
            source: 'es',
            target: 'en'
        }),
        contentType: 'application/json',
        success: function (response) {
            if (response && response.translatedText) {
                $("#nombre_en").val(response.translatedText);
            } else {
                simpleFallbackTranslation(text);
            }
        },
        error: function () {
            simpleFallbackTranslation(text);
        }
    });
}

// Última opción de traducción básica
function simpleFallbackTranslation(text) {
    // Si todas las APIs fallan, aplicar transformaciones básicas
    let translation = text
        .replace(/ción/g, 'tion')
        .replace(/dad/g, 'ty')
        .replace(/dor/g, 'tor')
        .replace(/ar$/g, 'ate')
        .replace(/co$/g, 'cal')
        .replace(/ía/g, 'ia')
        .replace(/ico$/g, 'ical')
        .replace(/ista/g, 'ist')
        .replace(/ismo/g, 'ism')
        .replace(/eo$/g, 'ea')
        .replace(/ble$/g, 'ble');

    // Capitalizar primera letra si el original también lo estaba
    if (text[0] === text[0].toUpperCase()) {
        translation = translation.charAt(0).toUpperCase() + translation.slice(1);
    }

    $("#nombre_en").val(translation);

    // Informar al usuario que es una traducción aproximada
    Swal.fire({
        icon: 'info',
        title: 'Traducción aproximada',
        text: 'Por favor, verifica y ajusta la traducción si es necesario',
        toast: true,
        position: 'top-end',
        showConfirmButton: false,
        timer: 3000
    });
}

function loadCategories() {
    $.ajax({
        url: 'database/model/categorias.php',
        type: 'POST',
        data: { "action": "getCategorias" },
        success: function (response) {
            try {
                let categorias = JSON.parse(response);

                // Si ya existe la tabla, destruirla para recrearla
                if ($.fn.DataTable.isDataTable('#categoryTable')) {
                    $('#categoryTable').DataTable().destroy();
                }

                $('#categoryTable').DataTable({
                    "paging": true,
                    "pageLength": 10,
                    "lengthMenu": [5, 10, 25, 50, 100],
                    "searching": true,
                    "info": true,
                    "ordering": true,
                    "responsive": true,
                    "data": categorias,
                    "columns": [
                        {
                            "data": null,
                            "render": function (data, type, row, meta) {
                                return meta.row + 1;  // Contador
                            }
                        },
                        { "data": "nombre_es" },
                        { "data": "nombre_en" },
                        {
                            "data": "destacado",
                            "render": function (data) {
                                return data == 1 ?
                                    '<span class="badge bg-success">Sí</span>' :
                                    '<span class="badge bg-secondary">No</span>';
                            }
                        },
                        {
                            "data": "status",
                            "render": function (data) {
                                return data == 1 ?
                                    '<span class="badge bg-success">Activo</span>' :
                                    '<span class="badge bg-danger">Inactivo</span>';
                            }
                        },
                        {
                            "data": null,
                            "render": function (data, type, row) {
                                let buttons = `<div class="btn-group" role="group">
                                    <button class="btn btn-primary btn-sm" onclick="editCategoria(${row.id_categoria})">
                                        <i class="fa-solid fa-pen-to-square"></i>
                                    </button>`;

                                // Condición para mostrar el botón de eliminar o restaurar según el status
                                if (row.status == 1) {
                                    buttons += `
                                    <button class="btn btn-danger btn-sm" onclick="deleteCategoria(${row.id_categoria})">
                                        <i class="fa-solid fa-trash"></i>
                                    </button>`;
                                } else {
                                    buttons += `
                                    <button class="btn btn-success btn-sm" onclick="restoreCategoria(${row.id_categoria})">
                                        <i class="fa-solid fa-rotate-right"></i>
                                    </button>`;
                                }

                                buttons += `</div>`;
                                return buttons;
                            }
                        }
                    ],
                    "language": {
                        "url": "//cdn.datatables.net/plug-ins/1.13.6/i18n/es-ES.json"
                    }
                });
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                Swal.fire({
                    icon: "error",
                    title: "Error",
                    text: "Error al cargar las categorías"
                });
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            Swal.fire({
                icon: "error",
                title: "Error",
                text: "Error de conexión al servidor"
            });
        }
    });
}

function saveCategory() {
    // Validar el formulario
    let id_categoria = $("#id_categoria").val();
    let nombre_es = $("#nombre_es").val().trim();
    let nombre_en = $("#nombre_en").val().trim();
    let destacado = $("#destacado").val();

    if (!nombre_es || !nombre_en || !destacado) {
        Swal.fire({
            icon: "error",
            title: "Error de validación",
            text: "Todos los campos son obligatorios"
        });
        return;
    }

    // Determinar si es creación o actualización
    let action = id_categoria ? "updateCategoria" : "addCategoria";
    let formData = new FormData(document.getElementById("addCategoryForm"));
    formData.append("action", action);

    // Enviar solicitud AJAX
    $.ajax({
        url: "database/model/categorias.php",
        type: "POST",
        data: formData,
        processData: false,
        contentType: false,
        success: function (response) {
            try {
                let result = JSON.parse(response);

                Swal.fire({
                    icon: result.status,
                    title: result.message,
                    showConfirmButton: false,
                    timer: 1500
                }).then(() => {
                    if (result.status === "success") {
                        $('#addCategoryModal').modal('hide');
                        loadCategories();
                    }
                });
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                Swal.fire({
                    icon: "error",
                    title: "Error",
                    text: "Error al procesar la respuesta del servidor"
                });
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            Swal.fire({
                icon: "error",
                title: "Error",
                text: "Error de conexión al servidor"
            });
        }
    });
}

function editCategoria(id) {
    $.ajax({
        url: "database/model/categorias.php",
        type: "POST",
        data: { "action": "getCategoria", "id": id },
        success: function (response) {
            try {
                let categoria = JSON.parse(response);

                if (categoria && categoria.id_categoria) {
                    $("#id_categoria").val(categoria.id_categoria);
                    $("#nombre_es").val(categoria.nombre_es);
                    $("#nombre_en").val(categoria.nombre_en);
                    $("#destacado").val(categoria.destacado);

                    $("#addCategoryModalLabel").html('Editar Categoría <i class="fa-solid fa-pen-to-square"></i>');
                    $("#btn-save-category").text("Actualizar categoría");
                    $("#addCategoryModal").modal("show");
                } else {
                    Swal.fire({
                        icon: "error",
                        title: "Error",
                        text: "No se pudo cargar la información de la categoría"
                    });
                }
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                Swal.fire({
                    icon: "error",
                    title: "Error",
                    text: "Error al procesar la respuesta del servidor"
                });
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            Swal.fire({
                icon: "error",
                title: "Error",
                text: "Error de conexión al servidor"
            });
        }
    });
}

function deleteCategoria(id) {
    Swal.fire({
        title: "¿Estás seguro?",
        text: "Esta acción no se puede revertir",
        icon: "warning",
        showCancelButton: true,
        confirmButtonColor: "#3085d6",
        cancelButtonColor: "#d33",
        confirmButtonText: "Sí, eliminar",
        cancelButtonText: "Cancelar"
    }).then((result) => {
        if (result.isConfirmed) {
            $.ajax({
                url: "database/model/categorias.php",
                type: "POST",
                data: { "action": "deleteCategoria", "id": id },
                success: function (response) {
                    try {
                        let result = JSON.parse(response);

                        Swal.fire({
                            icon: result.status,
                            title: result.message,
                            showConfirmButton: false,
                            timer: 1500
                        }).then(() => {
                            if (result.status === "success") {
                                loadCategories();
                            }
                        });
                    } catch (e) {
                        console.error("Error al procesar la respuesta:", e);
                        Swal.fire({
                            icon: "error",
                            title: "Error",
                            text: "Error al procesar la respuesta del servidor"
                        });
                    }
                },
                error: function (xhr, status, error) {
                    console.error("Error AJAX:", error);
                    Swal.fire({
                        icon: "error",
                        title: "Error",
                        text: "Error de conexión al servidor"
                    });
                }
            });
        }
    });
}

function restoreCategoria(id) {
    Swal.fire({
        title: "¿Estás seguro?",
        text: "Esta acción restaurará la categoría",
        icon: "warning",
        showCancelButton: true,
        confirmButtonColor: "#3085d6",
        cancelButtonColor: "#d33",
        confirmButtonText: "Sí, restaurar",
        cancelButtonText: "Cancelar"
    }).then((result) => {
        if (result.isConfirmed) {
            $.ajax({
                url: "database/model/categorias.php",
                type: "POST",
                data: { "action": "activateCategoria", "id": id },
                success: function (response) {
                    try {
                        let result = JSON.parse(response);

                        Swal.fire({
                            icon: result.status,
                            title: result.message,
                            showConfirmButton: false,
                            timer: 1500
                        }).then(() => {
                            if (result.status === "success") {
                                loadCategories();
                            }
                        });
                    } catch (e) {
                        console.error("Error al procesar la respuesta:", e);
                        Swal.fire({
                            icon: "error",
                            title: "Error",
                            text: "Error al procesar la respuesta del servidor"
                        });
                    }
                },
                error: function (xhr, status, error) {
                    console.error("Error AJAX:", error);
                    Swal.fire({
                        icon: "error",
                        title: "Error",
                        text: "Error de conexión al servidor"
                    });
                }
            });
        }
    });
}