// Deshabilitar Dropzone.autoDiscover ANTES de que se cargue el DOM
Dropzone.autoDiscover = false;

// Variables globales
let uploadedImageNames = [];
let pdfFileName = null;
let autocadFileName = null;
let existingImages = [];
let producto_imagen_principal = null;

/**
 * Función para mostrar mensajes de depuración en consola
 */
function debug(titulo, mensaje, data = null) {
    console.log(`📌 ${titulo}:`, mensaje, data || '');
}

document.addEventListener('DOMContentLoaded', function () {
    // Inicializar componentes
    initDropzones();
    loadSubcategorias();
    setupTranslation();

    // Botón guardar y cancelar
    document.getElementById('guardar').addEventListener('click', guardarProducto);
    document.getElementById('cancelar').addEventListener('click', function (e) {
        e.preventDefault();
        window.location.href = "productos.php";
    });

    // Prevenir envío de formulario con Enter
    document.querySelectorAll('#productoForm input, #productoForm select, #productoForm textarea').forEach(function (element) {
        element.addEventListener('keydown', function (event) {
            if (event.key === 'Enter') {
                event.preventDefault();
            }
        });
    });

    // Configurar Summernote para la descripción
    $('#descripcion_es, #descripcion_en').summernote({
        height: 150,
        disableDragAndDrop: true,
        toolbar: [
            ['style', ['style']],
            ['font', ['bold', 'italic', 'underline', 'clear']],
            ['fontname', ['fontname']],
            ['color', ['color']],
            ['para', ['ul', 'ol', 'paragraph']]
        ],
        callbacks: {
            onImageUpload: function () {
                Swal.fire({
                    icon: "error",
                    title: "Error",
                    text: "No se permite subir imágenes en este campo.",
                    showCancelButton: false,
                    showConfirmButton: false,
                    timer: 1500
                });
            }
        }
    });

    // Crear input oculto para las imágenes si no existe
    if (!document.getElementById('imagenes')) {
        const imagenesInput = document.createElement('input');
        imagenesInput.type = 'hidden';
        imagenesInput.name = 'imagenes';
        imagenesInput.id = 'imagenes';
        document.getElementById('productoForm').appendChild(imagenesInput);
    }
});

function initDropzones() {
    // Verificar que los elementos existen antes de inicializar
    const elementosNecesarios = ['imagenesForm', 'carouselInner', 'imagenesCarousel', 'pdfForm', 'autocadForm'];
    let todosPresentar = true;

    elementosNecesarios.forEach(id => {
        if (!document.getElementById(id)) {
            console.error(`Elemento ${id} no encontrado en el DOM`);
            todosPresentar = false;
        }
    });

    if (!todosPresentar) {
        console.error('No se pueden inicializar los Dropzones porque faltan elementos DOM');
        return;
    }

    inicializarDropzoneImagenes();
    inicializarDropzonePDF();
    inicializarDropzoneAutocad();
}

/**
 * Inicializa el Dropzone para imágenes del producto
 */
function inicializarDropzoneImagenes() {
    const imagenesDropzone = new Dropzone("#imagenesForm", {
        url: "php/uploadImagenProducto.php",
        paramName: "file",
        uploadMultiple: false,
        maxFilesize: 2,
        maxFiles: 10,
        acceptedFiles: "image/*",
        addRemoveLinks: false, // No mostrar el enlace de eliminar de Dropzone
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten imágenes.",
        autoProcessQueue: true,
        previewsContainer: false, // No usar el contenedor por defecto
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Validación de tamaño y tipo de archivo
                if (file.size > this.options.maxFilesize * 1024 * 1024) {
                    const mensaje = `El archivo "${file.name}" es demasiado grande (${(file.size / (1024 * 1024)).toFixed(2)}MB). Tamaño máximo: ${this.options.maxFilesize}MB.`;
                    mostrarError("Archivo demasiado grande", mensaje);
                    this.removeFile(file);
                    return false;
                }

                if (!file.type.match(/image\/.*/)) {
                    mostrarError("Formato inválido", "Solo se permiten archivos de imagen.");
                    this.removeFile(file);
                    return false;
                }

                // Crear URL temporal para la previsualización
                file.tempURL = URL.createObjectURL(file);
                file.tempName = file.name;
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        // Agregar a la lista de imágenes subidas
                        uploadedImageNames.push(data.filename);
                        document.getElementById('imagenes').value = uploadedImageNames.join(',');

                        // Asignar el nombre real del archivo al objeto file
                        file.serverName = data.filename;

                        // Añadir a existingImages para mantener consistencia
                        existingImages.push({
                            id: Date.now(), // ID temporal
                            imagen: data.filename,
                            principal: existingImages.length === 0 ? 1 : 0
                        });

                        // Si aún no hay imagen principal, marcar esta como principal
                        if (uploadedImageNames.length === 1) {
                            producto_imagen_principal = data.filename;
                        }

                        // Actualizar carrusel para mostrar la imagen recién subida
                        actualizarCarruselDirecto();
                    } else {
                        console.error("Error al subir imagen:", data.message);
                        this.removeFile(file);
                        mostrarError("Error", data.message);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                    mostrarError("Error", "Error al procesar la respuesta del servidor");
                }
            });

            this.on("removedfile", function (file) {
                // Si el archivo tenía un nombre asignado por el servidor
                if (file.serverName) {
                    const filename = file.serverName;

                    // Eliminar del array local
                    const imageIndex = uploadedImageNames.indexOf(filename);
                    if (imageIndex > -1) {
                        uploadedImageNames.splice(imageIndex, 1);
                        document.getElementById('imagenes').value = uploadedImageNames.join(',');
                    }

                    // Eliminar de existingImages
                    const existingIndex = existingImages.findIndex(img => img.imagen === filename);
                    if (existingIndex > -1) {
                        // Si era la principal, resetear
                        if (existingImages[existingIndex].principal == 1 || existingImages[existingIndex].imagen === producto_imagen_principal) {
                            producto_imagen_principal = null;
                            // Si quedan imágenes, marcar la primera como principal
                            if (existingImages.length > 1) {
                                // Buscar el primer elemento que no sea el eliminado
                                const nuevoIndex = existingImages.findIndex((img, idx) => idx !== existingIndex);
                                if (nuevoIndex !== -1) {
                                    existingImages[nuevoIndex].principal = 1;
                                    producto_imagen_principal = existingImages[nuevoIndex].imagen;
                                }
                            }
                        }
                        existingImages.splice(existingIndex, 1);
                    }

                    // Eliminar del servidor
                    $.ajax({
                        url: 'php/deleteImagenProducto.php',
                        type: 'POST',
                        data: { filename: filename }
                    });
                }

                // Actualizar carrusel después de eliminar
                actualizarCarruselDirecto();
            });
        }
    });

    return imagenesDropzone;
}

/**
 * Actualiza el carrusel directamente sin depender del Dropzone
 */
function actualizarCarruselDirecto() {
    const inner = document.getElementById("carouselInner");
    const carousel = document.getElementById("imagenesCarousel");

    // Verificar elementos DOM
    if (!inner || !carousel) {
        console.error('No se encontraron los elementos del carrusel en el DOM');
        return;
    }

    // Verificar si tenemos imágenes
    if (!existingImages || existingImages.length === 0) {
        console.warn('No hay imágenes para mostrar');
        carousel.style.display = 'none';
        return;
    }

    // Mostrar carrusel si hay imágenes
    carousel.style.display = 'block';

    // Limpiar contenedor
    inner.innerHTML = "";

    // Crear elementos para cada imagen
    existingImages.forEach((img, index) => {
        const isActive = index === 0;
        const isPrincipal = img.principal == 1 || img.imagen === producto_imagen_principal;

        // URL absoluta para la imagen
        const imgSrc = `${window.location.origin}/cye/sistema/img/productos/${img.imagen}`;

        // Crear elemento del carrusel
        const item = document.createElement("div");
        item.classList.add("carousel-item");
        if (isActive) item.classList.add("active");
        if (isPrincipal) item.classList.add("dz-principal");

        const wrapper = document.createElement("div");
        wrapper.className = "position-relative";

        // Imagen
        const imgEl = document.createElement("img");
        imgEl.src = imgSrc;
        imgEl.className = "d-block w-100";
        imgEl.style.maxHeight = "300px"; // Limitar altura para mejor visualización
        imgEl.style.objectFit = "contain"; // Mantener proporción de la imagen
        imgEl.alt = img.imagen;
        imgEl.onerror = function () {
            console.error(`No se pudo cargar la imagen: ${imgSrc}`);
            this.src = "img/placeholder.png"; // Imagen de reemplazo
            this.style.border = "1px solid red";

            // Intentar con rutas alternativas
            mostrarImagenDiagnostico(img.imagen);
        };

        wrapper.appendChild(imgEl);

        // Botones de acción
        const actionButtons = document.createElement("div");
        actionButtons.className = "carousel-div-btns position-absolute top-0 end-0 p-2";

        // Botón principal
        const principalBtn = document.createElement("button");
        principalBtn.className = `btn btn-sm ${isPrincipal ? 'btn-success' : 'btn-primary'} principal-button`;
        principalBtn.textContent = isPrincipal ? "Principal ✓" : "Principal";
        principalBtn.addEventListener("click", function (e) {
            e.preventDefault();
            e.stopPropagation();

            // Quitar marca de principal de todas las imágenes
            existingImages.forEach(image => {
                image.principal = 0;
            });

            // Marcar esta como principal
            img.principal = 1;
            producto_imagen_principal = img.imagen;

            // Actualizar carrusel
            actualizarCarruselDirecto();
        });

        // Botón eliminar
        const removeBtn = document.createElement("button");
        removeBtn.className = "btn btn-sm btn-danger me-2";
        removeBtn.textContent = "Eliminar";
        removeBtn.addEventListener("click", function (e) {
            e.preventDefault();
            e.stopPropagation();

            // Obtener Dropzone
            const imagenesDropzone = Dropzone.forElement("#imagenesForm");
            if (imagenesDropzone) {
                // Buscar el archivo en dropzone
                const file = imagenesDropzone.files.find(f => f.serverName === img.imagen);
                if (file) {
                    // Usar el método de dropzone para eliminar
                    imagenesDropzone.removeFile(file);
                } else {
                    // Si no está en dropzone, eliminar manualmente
                    eliminarImagen(img.imagen);
                }
            } else {
                eliminarImagen(img.imagen);
            }
        });

        actionButtons.appendChild(removeBtn);
        actionButtons.appendChild(principalBtn);

        wrapper.appendChild(actionButtons);
        item.appendChild(wrapper);
        inner.appendChild(item);
    });

    // Inicializar carrusel Bootstrap
    try {
        new bootstrap.Carousel(document.getElementById('imagenesCarousel'));
    } catch (error) {
        console.error('Error al inicializar Bootstrap Carousel:', error);
    }
}

/**
 * Función auxiliar para eliminar imágenes (sin usar Dropzone)
 */
function eliminarImagen(nombreImagen) {
    // Eliminar del array de existingImages
    const index = existingImages.findIndex(image => image.imagen === nombreImagen);
    if (index > -1) {
        // Si era la principal, resetear
        if (existingImages[index].principal == 1 || existingImages[index].imagen === producto_imagen_principal) {
            producto_imagen_principal = null;
            // Si quedan imágenes, marcar la primera como principal
            if (existingImages.length > 1) {
                const nuevoIndex = existingImages.findIndex((img, idx) => idx !== index);
                if (nuevoIndex !== -1) {
                    existingImages[nuevoIndex].principal = 1;
                    producto_imagen_principal = existingImages[nuevoIndex].imagen;
                }
            }
        }
        existingImages.splice(index, 1);
    }

    // Eliminar del array de nombres
    const nameIndex = uploadedImageNames.indexOf(nombreImagen);
    if (nameIndex > -1) {
        uploadedImageNames.splice(nameIndex, 1);
        document.getElementById('imagenes').value = uploadedImageNames.join(',');
    }

    // Eliminar del servidor
    $.ajax({
        url: 'php/deleteImagenProducto.php',
        type: 'POST',
        data: { filename: nombreImagen },
        success: function (response) {
            try {
                const result = JSON.parse(response);
                if (result.status === 'success') {
                    
                } else {
                    console.error('Error al eliminar imagen:', result.message);
                }
            } catch (e) {
                console.error('Error al procesar respuesta:', e);
            }
        },
        error: function (xhr, status, error) {
            console.error('Error AJAX al eliminar imagen:', error);
        }
    });

    // Actualizar carrusel
    actualizarCarruselDirecto();
}

/**
 * Muestra imagen de diagnóstico para verificar rutas
 */
function mostrarImagenDiagnostico(imagen) {
    const rutaBase = `${window.location.origin}/cye/sistema/img/productos/`;
    const rutaImagen = rutaBase + imagen;

    const testImagen = new Image();
    testImagen.onload = function () {
    };
    testImagen.onerror = function () {

        const alternativas = [
            `${window.location.origin}/sistema/img/productos/${imagen}`,
            `/cye/sistema/img/productos/${imagen}`,
            `/sistema/img/productos/${imagen}`,
            `img/productos/${imagen}`
        ];

        alternativas.forEach(ruta => {
            const test = new Image();
            test.onload = function () {
    
            };
            test.onerror = function () {
                
            };
            test.src = ruta;
        });
    };
    testImagen.src = rutaImagen;
}

/**
 * Mantener la función actualizarCarrusel para compatibilidad
 */
function actualizarCarrusel() {
    actualizarCarruselDirecto();
}

/**
 * Inicializa el Dropzone para archivos PDF
 */
function inicializarDropzonePDF() {
    const pdfDropzone = new Dropzone("#pdfForm", {
        url: "php/uploadPdf.php",
        paramName: "plano",
        maxFilesize: 5, // MB
        maxFiles: 1,
        acceptedFiles: "application/pdf",
        addRemoveLinks: false, // Cambiado a false para evitar duplicados
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten archivos PDF.",
        previewTemplate: "<div style='display:none'></div>", // Ocultamos la previsualización predeterminada
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Eliminar cualquier previsualización anterior
                const prevContainer = document.querySelector('#pdfForm').nextElementSibling;
                if (prevContainer) {
                    const existingPreviews = prevContainer.querySelectorAll('.pdf-preview');
                    existingPreviews.forEach(el => el.remove());
                }

                // Solo validar el archivo sin mostrar alertas
                if (!validarArchivoSilencioso(file, this)) return;
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        pdfFileName = data.filename;
                        document.getElementById('pdf').value = pdfFileName;

                        // Mostrar previsualización del PDF
                        mostrarPrevisualizacionPDF(file, myDropzone);
                    } else {
                        console.error("Error al subir PDF:", data.message);
                        this.removeFile(file);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                }
            });

            this.on("removedfile", function (file) {
                // Si hay un PDF subido, eliminarlo del servidor de forma silenciosa
                if (pdfFileName) {
                    // Eliminar la previsualización del DOM si existe
                    if (file.previewElement) {
                        file.previewElement.remove();
                    }

                    $.ajax({
                        url: 'php/deleteFile.php',
                        type: 'POST',
                        data: {
                            filename: pdfFileName,
                            type: 'pdf'
                        },
                        success: function (response) {
                            try {
                                const result = JSON.parse(response);
                                if (result.status === 'success') {
                                    pdfFileName = null;
                                    document.getElementById('pdf').value = "";
                                } else {
                                    console.error('Error al eliminar PDF:', result.message);
                                }
                            } catch (e) {
                                console.error("Error al procesar la respuesta:", e);
                            }
                        }
                    });
                }
            });

            this.on("maxfilesexceeded", function (file) {
                this.removeAllFiles();
                this.addFile(file);
            });
        }
    });

    return pdfDropzone;
}

/**
 * Valida un archivo sin mostrar alertas
 */
function validarArchivoSilencioso(file, dropzone, tipo = '') {
    // No validar archivos mock
    if (!file.size && file.accepted) {
        return true;
    }

    // Validar tamaño
    if (file.size > dropzone.options.maxFilesize * 1024 * 1024) {
        console.error(`El archivo "${file.name}" es demasiado grande (${(file.size / (1024 * 1024)).toFixed(2)}MB). Tamaño máximo: ${dropzone.options.maxFilesize}MB.`);
        dropzone.removeFile(file);
        return false;
    }

    // Validar tipo para imágenes
    if (tipo === 'image' && !file.type.match(/image\/.*/)) {
        console.error("Formato inválido. Solo se permiten archivos de imagen.");
        dropzone.removeFile(file);
        return false;
    }

    return true;
}


/**
 * Inicializa el Dropzone para archivos AutoCAD
 */
function inicializarDropzoneAutocad() {
    const autocadDropzone = new Dropzone("#autocadForm", {
        url: "php/uploadAutocad.php",
        paramName: "file",
        maxFilesize: 10, // MB
        maxFiles: 1,
        acceptedFiles: ".dwg,.dxf,.dwf",
        addRemoveLinks: true,
        dictDefaultMessage: "",
        dictRemoveFile: "Eliminar",
        dictFileTooBig: "El archivo es demasiado grande ({{filesize}}MB). Tamaño máximo: {{maxFilesize}}MB.",
        dictInvalidFileType: "Tipo de archivo no válido. Solo se permiten archivos .dwg, .dxf o .dwf",
        previewTemplate: "<div style='display:none'></div>", // Ocultamos la previsualización predeterminada
        clickable: true,

        init: function () {
            const myDropzone = this;

            this.on("addedfile", function (file) {
                // Validación de tamaño y tipo para archivos reales (no mock)
                if (validarArchivo(file, this) === false) return;

                // Mostrar previsualización personalizada
                mostrarPrevisualizacionAutocad(file, myDropzone);
            });

            this.on("success", function (file, response) {
                try {
                    const data = JSON.parse(response);
                    if (data.status === 'success') {
                        autocadFileName = data.filename;
                        document.getElementById('autocard').value = autocadFileName;
                        mostrarNotificacionExito('Archivo AutoCAD subido correctamente');
                    } else {
                        console.error("Error al subir AutoCAD:", data.message);
                        this.removeFile(file);
                        mostrarError("Error", data.message);
                    }
                } catch (e) {
                    console.error("Error al procesar respuesta:", e);
                    this.removeFile(file);
                    mostrarError("Error", "Error al procesar la respuesta del servidor");
                }
            });

            this.on("removedfile", function (file) {
                // No eliminar inmediatamente del DOM
                const previewElement = file.previewElement;

                // Si hay un archivo AutoCAD subido, eliminarlo del servidor
                if (autocadFileName) {
                    $.ajax({
                        url: 'php/deleteFile.php',
                        type: 'POST',
                        data: {
                            filename: autocadFileName,
                            type: 'autocad'
                        },
                        success: function (response) {
                            try {
                                const result = JSON.parse(response);
                                if (result.status === 'success') {
                                    // Solo eliminar del DOM tras confirmar eliminación
                                    if (previewElement && previewElement.parentNode) {
                                        previewElement.parentNode.removeChild(previewElement);
                                    }
                                    autocadFileName = null;
                                    document.getElementById('autocard').value = "";
                                } else {
                                    mostrarError("Error", result.message || 'Error al eliminar el archivo AutoCAD');
                                }
                            } catch (e) {
                                console.error("Error al procesar la respuesta:", e);
                            }
                        },
                        error: function () {
                            mostrarError("Error", "Error de conexión al eliminar el archivo AutoCAD");
                        }
                    });
                }
            });

            this.on("maxfilesexceeded", function (file) {
                this.removeAllFiles();
                this.addFile(file);
            });
        }
    });

    return autocadDropzone;
}

/**
 * Valida un archivo antes de procesarlo (tamaño y tipo)
 */
function validarArchivo(file, dropzone, tipo = '') {
    // No validar archivos mock
    if (!file.size && file.accepted) {
        return true;
    }

    // Validar tamaño
    if (file.size > dropzone.options.maxFilesize * 1024 * 1024) {
        const mensaje = `El archivo "${file.name}" es demasiado grande (${(file.size / (1024 * 1024)).toFixed(2)}MB). Tamaño máximo: ${dropzone.options.maxFilesize}MB.`;
        mostrarError("Archivo demasiado grande", mensaje);
        dropzone.removeFile(file);
        return false;
    }

    // Validar tipo para imágenes
    if (tipo === 'image' && !file.type.match(/image\/.*/)) {
        mostrarError("Formato inválido", "Solo se permiten archivos de imagen.");
        dropzone.removeFile(file);
        return false;
    }

    return true;
}
/**
 * Muestra la previsualización de un archivo PDF
 */
function mostrarPrevisualizacionPDF(file, dropzone) {

    // Obtener el contenedor de forma más segura
    const container = document.querySelector('#pdfForm').closest('.card-body');
    if (!container) {
        console.error("No se pudo encontrar el contenedor para la previsualización del PDF");
        return;
    }

    // Limpiar cualquier previsualización anterior
    const existingPreviews = container.querySelectorAll('.pdf-preview');
    existingPreviews.forEach(el => el.remove());

    // Crear previsualización personalizada
    const pdfPreview = document.createElement('div');
    pdfPreview.className = 'pdf-preview mt-3 p-3 border rounded';

    const fileInfo = document.createElement('div');
    fileInfo.className = 'd-flex align-items-center';

    const icon = document.createElement('i');
    icon.className = 'fas fa-file-pdf text-danger me-2 fa-2x';

    const fileName = document.createElement('span');
    fileName.textContent = file.name;
    fileName.className = 'flex-grow-1';

    const removeBtn = document.createElement('button');
    removeBtn.className = 'btn btn-sm btn-danger ms-2';
    removeBtn.textContent = 'Eliminar';
    removeBtn.addEventListener('click', function (e) {
        e.preventDefault();
        e.stopPropagation();
        dropzone.removeFile(file);
    });

    // Ensamblar elementos
    fileInfo.appendChild(icon);
    fileInfo.appendChild(fileName);
    fileInfo.appendChild(removeBtn);
    pdfPreview.appendChild(fileInfo);

    // Agregar al DOM
    container.appendChild(pdfPreview);

    // Guardar referencia al elemento para poder eliminarlo más tarde
    file.previewElement = pdfPreview;
}

/**
 * Muestra la previsualización de un archivo AutoCAD
 */
function mostrarPrevisualizacionAutocad(file, dropzone) {
    // Crear previsualización personalizada
    const autocadPreview = document.createElement('div');
    autocadPreview.className = 'autocad-preview mt-3 p-3 border rounded';

    const fileInfo = document.createElement('div');
    fileInfo.className = 'd-flex align-items-center';

    const icon = document.createElement('i');
    icon.className = 'fas fa-file-alt text-primary me-2 fa-2x';

    const fileName = document.createElement('span');
    fileName.textContent = file.name;
    fileName.className = 'flex-grow-1';

    const removeBtn = document.createElement('button');
    removeBtn.className = 'btn btn-sm btn-danger ms-2';
    removeBtn.textContent = 'Eliminar';
    removeBtn.addEventListener('click', function (e) {
        e.preventDefault();
        e.stopPropagation();
        dropzone.removeFile(file);
    });

    // Ensamblar elementos
    fileInfo.appendChild(icon);
    fileInfo.appendChild(fileName);
    fileInfo.appendChild(removeBtn);
    autocadPreview.appendChild(fileInfo);

    // Agregar al DOM
    document.querySelector('#autocadForm').nextElementSibling.appendChild(autocadPreview);

    // Guardar referencia al elemento para poder eliminarlo más tarde
    file.previewElement = autocadPreview;
}

function loadSubcategorias() {
    $.ajax({
        url: 'database/model/productos.php',
        type: 'POST',
        data: { "action": "getActiveSubcategorias" },
        success: function (response) {
            try {
                let subcategorias = JSON.parse(response);
                let select = document.getElementById('id_subcategoria');

                if (select) {
                    select.innerHTML = '<option value="">Selecciona una subcategoría</option>';

                    // Agrupar por categoría
                    const categorias = {};
                    subcategorias.forEach(item => {
                        if (!categorias[item.id_categoria]) {
                            categorias[item.id_categoria] = {
                                nombre: `${item.categoria_es} / ${item.categoria_en}`,
                                subcategorias: []
                            };
                        }
                        categorias[item.id_categoria].subcategorias.push(item);
                    });

                    // Crear optgroups por categoría
                    for (const catId in categorias) {
                        const optgroup = document.createElement('optgroup');
                        optgroup.label = categorias[catId].nombre;

                        categorias[catId].subcategorias.forEach(subcat => {
                            const option = document.createElement('option');
                            option.value = subcat.id_subcategoria;
                            option.textContent = `${subcat.nombre_es} / ${subcat.nombre_en}`;
                            optgroup.appendChild(option);
                        });

                        select.appendChild(optgroup);
                    }
                }
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                mostrarError("Error", "Error al cargar las subcategorías");
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            mostrarError("Error", "Error de conexión al servidor");
        }
    });
}

function setupTranslation() {
    // Sistema de traducción automática español -> inglés
    let typingTimer;
    const doneTypingInterval = 800; // tiempo en ms

    // Evento para el nombre en español
    const nombreEs = document.getElementById('nombre_es');
    if (nombreEs) {
        nombreEs.addEventListener('input', function () {
            clearTimeout(typingTimer);
            const texto = this.value.trim();

            if (texto === '') {
                document.getElementById('nombre_en').value = '';
                return;
            }

            typingTimer = setTimeout(function () {
                if (texto.length > 0) {
                    // Primero probamos con diccionario local
                    let traduccionLocal = localTranslate(texto);
                    if (traduccionLocal) {
                        document.getElementById('nombre_en').value = traduccionLocal;
                    } else {
                        // Si no hay coincidencia local, usamos API gratuita
                        translateText(texto, 'nombre_en');
                    }
                }
            }, doneTypingInterval);
        });
    }

    // Evento para descripción en español - MEJORADO
    if ($('#descripcion_es').length) {
        // Usar evento change en lugar de input para Summernote
        $('#descripcion_es').on('summernote.change', function () {
            clearTimeout(typingTimer);
            const textoHtml = $(this).summernote('code').trim();

            if (textoHtml === '' || textoHtml === '<p><br></p>') {
                $('#descripcion_en').summernote('code', '');
                return;
            }

            typingTimer = setTimeout(function () {
                if (textoHtml.length > 0) {
                    // Extraer texto sin etiquetas HTML de manera más robusta
                    const textoPlano = extraerTextoPlano(textoHtml);

                    if (textoPlano.trim().length > 0) {
                        // Usar traducción local primero si es un texto corto
                        if (textoPlano.length < 100) {
                            const traduccionLocal = localTranslate(textoPlano);
                            if (traduccionLocal) {
                                $('#descripcion_en').summernote('code', '<p>' + traduccionLocal + '</p>');
                                return;
                            }
                        }

                        // Si no hay traducción local o es un texto largo, usar API
                        translateText(textoPlano, 'descripcion_en', true);
                    }
                }
            }, doneTypingInterval);
        });

        // Añadir también escucha para cambios manuales (keyup)
        $('#descripcion_es').on('summernote.keyup', function () {
            clearTimeout(typingTimer);
            const textoHtml = $(this).summernote('code').trim();

            if (textoHtml === '' || textoHtml === '<p><br></p>') {
                $('#descripcion_en').summernote('code', '');
                return;
            }

            typingTimer = setTimeout(function () {
                const textoPlano = extraerTextoPlano(textoHtml);
                if (textoPlano.trim().length > 0) {
                    translateText(textoPlano, 'descripcion_en', true);
                }
            }, doneTypingInterval * 2); // Tiempo más largo para evitar llamadas excesivas
        });
    }
}

/**
 * Extrae texto plano de un fragmento HTML
 */
function extraerTextoPlano(html) {
    const tempDiv = document.createElement('div');
    tempDiv.innerHTML = html;
    return tempDiv.textContent || tempDiv.innerText || '';
}

// Función de traducción local con términos comunes
function localTranslate(text) {
    // Diccionario de términos comunes (ampliable)
    const commonTranslations = {
        "instalación eléctrica": "electrical installation",
        "poste de luz": "light pole",
        "tablero eléctrico": "electrical panel",
        "cable": "cable",
        "transformador": "transformer",
        "energía solar": "solar energy",
        "iluminación": "lighting",
        "panel solar": "solar panel",
        "interruptor": "switch",
        "tomacorriente": "power outlet",
        "conductor eléctrico": "electrical conductor",
        "clavija": "plug",
        "enchufe": "socket",
        "fusible": "fuse",
        "aislante": "insulator",
        "subestación": "substation",
        "generador": "generator",
        "batería": "battery",
        "inversor": "inverter",
        "electricista": "electrician",
        "herramientas": "tools",
        "instalador": "installer",
        "ducto": "duct",
        "canaleta": "cable tray",
        "conexión": "connection",
        "sistema eléctrico": "electrical system"
    };

    // Convertir a minúsculas para buscar en el diccionario
    const textLower = text.toLowerCase();

    // Comprobar si existe una traducción exacta
    if (commonTranslations[textLower]) {
        // Mantener la capitalización original
        if (text[0] === text[0].toUpperCase()) {
            return commonTranslations[textLower].charAt(0).toUpperCase() +
                commonTranslations[textLower].slice(1);
        }
        return commonTranslations[textLower];
    }

    // Devolver null si no hay coincidencia en el diccionario
    return null;
}

function translateText(text, targetId, isHtml = false) {
    const targetElement = document.getElementById(targetId);
    if (!targetElement) return;

    // Mostrar indicador de carga
    if (isHtml) {
        $('#' + targetId).next('.note-editor').addClass('loading-translation');
    } else {
        targetElement.classList.add('loading-translation');
    }

    // Usar la API de MyMemory (gratuita con límites)
    $.ajax({
        url: `https://api.mymemory.translated.net/get?q=${encodeURIComponent(text)}&langpair=es|en`,
        type: 'GET',
        success: function (data) {
            if (data && data.responseData && data.responseData.translatedText) {
                if (isHtml) {
                    // Preservar formato HTML básico
                    let traduccion = data.responseData.translatedText;

                    // Asegurar que la traducción tenga etiquetas de párrafo
                    if (!traduccion.startsWith('<')) {
                        traduccion = '<p>' + traduccion + '</p>';
                    }

                    $('#' + targetId).summernote('code', traduccion);
                } else {
                    targetElement.value = data.responseData.translatedText;
                }
            } else {
                console.warn("API primaria falló, usando respaldo:", data);
                fallbackTranslation(text, targetId, isHtml);
            }

            if (isHtml) {
                $('#' + targetId).next('.note-editor').removeClass('loading-translation');
            } else {
                targetElement.classList.remove('loading-translation');
            }
        },
        error: function (xhr, status, error) {
            console.error(`Error en API primaria (${targetId}):`, error);
            fallbackTranslation(text, targetId, isHtml);

            if (isHtml) {
                $('#' + targetId).next('.note-editor').removeClass('loading-translation');
            } else {
                targetElement.classList.remove('loading-translation');
            }
        }
    });
}

// Función de respaldo si falla la primera opción
function fallbackTranslation(text, targetId, isHtml = false) {
    // Usar LibreTranslate como alternativa
    $.ajax({
        url: 'https://libretranslate.de/translate',
        type: 'POST',
        data: JSON.stringify({
            q: text,
            source: 'es',
            target: 'en'
        }),
        contentType: 'application/json',
        success: function (response) {
            if (response && response.translatedText) {
                if (isHtml) {
                    $('#' + targetId).summernote('code', '<p>' + response.translatedText + '</p>');
                } else {
                    document.getElementById(targetId).value = response.translatedText;
                }
            } else {
                simpleFallbackTranslation(text, targetId, isHtml);
            }
        },
        error: function () {
            simpleFallbackTranslation(text, targetId, isHtml);
        }
    });
}

// Última opción de traducción básica
function simpleFallbackTranslation(text, targetId, isHtml = false) {
    // Si todas las APIs fallan, aplicar transformaciones básicas
    let translation = text
        .replace(/ción/g, 'tion')
        .replace(/dad/g, 'ty')
        .replace(/dor/g, 'tor')
        .replace(/ar$/g, 'ate')
        .replace(/co$/g, 'cal')
        .replace(/ía/g, 'ia')
        .replace(/ico$/g, 'ical')
        .replace(/ista/g, 'ist')
        .replace(/ismo/g, 'ism')
        .replace(/eo$/g, 'ea')
        .replace(/ble$/g, 'ble');

    // Capitalizar primera letra si el original también lo estaba
    if (text[0] === text[0].toUpperCase()) {
        translation = translation.charAt(0).toUpperCase() + translation.slice(1);
    }

    if (isHtml) {
        $('#' + targetId).summernote('code', '<p>' + translation + '</p>');
    } else {
        document.getElementById(targetId).value = translation;
    }

    // Informar al usuario que es una traducción aproximada
    mostrarNotificacion('info', 'Traducción aproximada', 'Por favor, verifica y ajusta la traducción si es necesario');
}

function guardarProducto() {
    // Validación básica
    const nombre_es = document.getElementById('nombre_es').value.trim();
    const nombre_en = document.getElementById('nombre_en').value.trim();
    const id_subcategoria = document.getElementById('id_subcategoria').value;
    const sku = document.getElementById('sku').value.trim();

    if (!nombre_es || !nombre_en || !id_subcategoria || !sku) {
        mostrarError('Error de validación', 'Por favor completa todos los campos obligatorios');
        return;
    }

    // Validar el contenido de los editores
    const descripcion_es = $('#descripcion_es').summernote('isEmpty') ? '' : $('#descripcion_es').summernote('code');
    const descripcion_en = $('#descripcion_en').summernote('isEmpty') ? '' : $('#descripcion_en').summernote('code');

    // Mostrar indicador de carga
    Swal.fire({
        title: 'Guardando producto...',
        text: 'Por favor espera',
        allowOutsideClick: false,
        didOpen: () => {
            Swal.showLoading();
        }
    });

    // Recopilar datos del formulario
    const formData = new FormData(document.getElementById('productoForm'));
    formData.append('action', 'createProducto');
    formData.append('descripcion_es', descripcion_es);
    formData.append('descripcion_en', descripcion_en);

    // Obtener la imagen principal
    let imagenPrincipal = null;
    if (existingImages && existingImages.length > 0) {
        const imgPrincipal = existingImages.find(img => img.principal == 1);
        if (imgPrincipal) {
            imagenPrincipal = imgPrincipal.imagen;
        } else if (producto_imagen_principal) {
            imagenPrincipal = producto_imagen_principal;
        } else {
            imagenPrincipal = existingImages[0].imagen;
        }
    }

    // Agregar imagen principal al formulario
    if (imagenPrincipal) {
        formData.append('imagen_principal', imagenPrincipal);
        console.log('Imagen principal seleccionada:', imagenPrincipal);
    }

    // Enviar solicitud AJAX
    $.ajax({
        url: 'database/model/productos.php',
        type: 'POST',
        data: formData,
        processData: false,
        contentType: false,
        success: function (response) {
            try {
                const result = JSON.parse(response);

                if (result.status === 'success') {
                    Swal.fire({
                        icon: 'success',
                        title: 'Producto guardado',
                        text: result.message,
                        showConfirmButton: false,
                        timer: 1500
                    }).then(() => {
                        window.location.href = 'productos.php';
                    });
                } else {
                    mostrarError('Error', result.message || 'Error al guardar el producto');
                }
            } catch (e) {
                console.error("Error al procesar la respuesta:", e);
                mostrarError('Error', 'Error al procesar la respuesta del servidor');
            }
        },
        error: function (xhr, status, error) {
            console.error("Error AJAX:", error);
            mostrarError('Error', 'Error de conexión al servidor');
        }
    });
}

/**
 * Muestra un mensaje de error usando SweetAlert
 * @param {string} titulo - Título del mensaje
 * @param {string} texto - Texto del mensaje
 */
function mostrarError(titulo, texto) {
    console.error(`${titulo}: ${texto}`);

    Swal.fire({
        icon: 'error',
        title: titulo,
        text: texto
    });
}

/**
 * Muestra una notificación de éxito
 * @param {string} mensaje - Mensaje a mostrar
 */
function mostrarNotificacionExito(mensaje) {
    Swal.fire({
        position: 'top-end',
        icon: 'success',
        title: mensaje,
        showConfirmButton: false,
        timer: 1500
    });
}

/**
 * Muestra una notificación genérica
 * @param {string} tipo - Tipo de notificación (success, error, warning, info)
 * @param {string} titulo - Título de la notificación
 * @param {string} mensaje - Mensaje a mostrar
 */
function mostrarNotificacion(tipo, titulo, mensaje) {
    Swal.fire({
        icon: tipo,
        title: titulo,
        text: mensaje,
        toast: true,
        position: 'top-end',
        showConfirmButton: false,
        timer: 3000
    });
}