<?php
if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['filename']) || !isset($_POST['type'])) {
    http_response_code(400);
    exit;
}

$filename = $_POST['filename'];
$type = $_POST['type']; // 'pdf' o 'autocad'
$id_producto = isset($_POST['id_producto']) ? $_POST['id_producto'] : null;

// Validar que el nombre de archivo no contenga caracteres peligrosos
if (preg_match('/[.\/\\\\]/', $filename)) {
    http_response_code(400);
    exit('Nombre de archivo no válido');
}

// Determinar la ruta según el tipo
if ($type === 'pdf') {
    $filePath = __DIR__ . '/../pdf/productos/' . $filename;
    $dbField = 'pdf';
} elseif ($type === 'autocad') {
    $filePath = __DIR__ . '/../archivos/autocad/' . $filename;
    $dbField = 'autocard';
} else {
    echo json_encode(['status' => 'error', 'message' => 'Tipo de archivo no válido']);
    exit;
}

// Si se proporcionó ID de producto, actualizar campo en la BD
if ($id_producto) {
    require_once __DIR__ . '/../database/DBconnection.php';
    $db = new DBconnection();
    $conn = $db->connect();
    
    try {
        // Actualizar a NULL el campo correspondiente
        $query = "UPDATE producto SET $dbField = NULL WHERE id = ?";
        $stmt = $conn->prepare($query);
        $stmt->execute([$id_producto]);
    } catch (Exception $e) {
        // Error al actualizar la BD
        echo json_encode(['status' => 'error', 'message' => 'Error de base de datos: ' . $e->getMessage()]);
        exit;
    }
}

// Eliminar archivo físico
if (file_exists($filePath)) {
    if (unlink($filePath)) {
        echo json_encode(['status' => 'success', 'message' => 'Archivo eliminado correctamente']);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'No se pudo eliminar el archivo']);
    }
} else {
    echo json_encode(['status' => 'success', 'message' => 'El archivo no existe pero se eliminó la referencia']);
}