<?php
if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['filename'])) {
    http_response_code(400);
    exit;
}

$filename = $_POST['filename'];
$id_producto = isset($_POST['id_producto']) ? $_POST['id_producto'] : null;

// Validar que el nombre de archivo no contenga caracteres peligrosos
if (preg_match('/[.\/\\\\]/', $filename)) {
    http_response_code(400);
    exit('Nombre de archivo no válido');
}

$filePath = __DIR__ . '/../img/productos/' . $filename;

// Si se proporcionó ID de producto, eliminar relación en la BD
if ($id_producto) {
    require_once __DIR__ . '/../database/DBconnection.php';
    $db = new DBconnection();
    $conn = $db->connect();
    
    try {
        // Eliminar la relación en la tabla imagen_producto
        $query = "DELETE FROM imagen_producto WHERE id_producto = ? AND imagen = ?";
        $stmt = $conn->prepare($query);
        $stmt->execute([$id_producto, $filename]);
    } catch (Exception $e) {
        // Error al eliminar de la BD
        echo json_encode(['status' => 'error', 'message' => 'Error de base de datos: ' . $e->getMessage()]);
        exit;
    }
}

// Eliminar archivo físico
if (file_exists($filePath)) {
    if (unlink($filePath)) {
        echo json_encode(['status' => 'success', 'message' => 'Archivo eliminado correctamente']);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'No se pudo eliminar el archivo']);
    }
} else {
    // Si el archivo no existe pero eliminamos la referencia de BD, considerarlo éxito
    echo json_encode(['status' => 'success', 'message' => 'El archivo no existe pero se eliminó la referencia']);
}