<?php
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    exit;
}

$uploadDir = __DIR__ . '/../archivos/autocad/';
if (!is_dir($uploadDir)) {
    mkdir($uploadDir, 0775, true);
}

if (!empty($_FILES['file']['name'])) {
    // Verificar errores
    if ($_FILES['file']['error'] !== UPLOAD_ERR_OK) {
        echo json_encode(['status' => 'error', 'message' => 'Error al subir el archivo']);
        exit;
    }
    
    // Verificar extensión
    $extension = strtolower(pathinfo($_FILES['file']['name'], PATHINFO_EXTENSION));
    $allowedExtensions = ['dwg', 'dxf', 'dwf'];
    
    if (!in_array($extension, $allowedExtensions)) {
        echo json_encode(['status' => 'error', 'message' => 'Tipo de archivo no permitido. Solo .dwg, .dxf, o .dwf']);
        exit;
    }
    
    // Verificar tamaño (10MB máximo)
    $maxSize = 10 * 1024 * 1024;
    if ($_FILES['file']['size'] > $maxSize) {
        echo json_encode(['status' => 'error', 'message' => 'El archivo es demasiado grande']);
        exit;
    }
    
    // Generar nombre único para el archivo
    $filename = uniqid() . '_' . basename($_FILES['file']['name']);
    $targetFile = $uploadDir . $filename;
    
    // Mover el archivo
    if (move_uploaded_file($_FILES['file']['tmp_name'], $targetFile)) {
        echo json_encode(['status' => 'success', 'filename' => $filename]);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'No se pudo guardar el archivo']);
    }
} else {
    echo json_encode(['status' => 'error', 'message' => 'No se recibió ningún archivo']);
}