<?php
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    exit;
}

$uploadDir = __DIR__ . '/../img/productos/';
if (!is_dir($uploadDir)) {
    mkdir($uploadDir, 0775, true);
}

if (!empty($_FILES['file']['name'])) {
    // Verificar errores
    if ($_FILES['file']['error'] !== UPLOAD_ERR_OK) {
        echo json_encode(['status' => 'error', 'message' => 'Error al subir el archivo']);
        exit;
    }

    // Verificar tipo de archivo
    $allowedTypes = ['image/jpeg', 'image/png', 'image/gif', 'image/webp'];
    $finfo = new finfo(FILEINFO_MIME_TYPE);
    $fileType = $finfo->file($_FILES['file']['tmp_name']);
    
    if (!in_array($fileType, $allowedTypes)) {
        echo json_encode(['status' => 'error', 'message' => 'Tipo de archivo no permitido']);
        exit;
    }
    
    // Verificar tamaño (2MB máximo)
    $maxSize = 2 * 1024 * 1024;
    if ($_FILES['file']['size'] > $maxSize) {
        echo json_encode(['status' => 'error', 'message' => 'El archivo es demasiado grande']);
        exit;
    }
    
    // Generar nombre único para el archivo
    $filename = uniqid() . '_' . basename($_FILES['file']['name']);
    $targetFile = $uploadDir . $filename;
    
    // Mover el archivo
    if (move_uploaded_file($_FILES['file']['tmp_name'], $targetFile)) {
        echo json_encode(['status' => 'success', 'filename' => $filename]);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'No se pudo guardar el archivo']);
    }
} else {
    echo json_encode(['status' => 'error', 'message' => 'No se recibió ningún archivo']);
}